## START: Set by rpmautospec
## (rpmautospec version 0.8.1)
## RPMAUTOSPEC: autorelease, autochangelog
%define autorelease(e:s:pb:n) %{?-p:0.}%{lua:
    release_number = 2;
    base_release_number = tonumber(rpm.expand("%{?-b*}%{!?-b:1}"));
    print(release_number + base_release_number - 1);
}%{?-e:.%{-e*}}%{?-s:.%{-s*}}%{!?-n:%{?dist}}
## END: Set by rpmautospec

# Force out of source build
%undefine __cmake_in_source_build

%global		upstream_version 3_6_0
#%%global       prerelease RC1

Name:           opensubdiv
Version:        3.6.1
Release:        %autorelease
Summary:        High performance subdivision surface libraries

# The entire source is Pixar except:
#
# MIT:
#   - glLoader/khrplatform.h
#   - documentation/tipuesearch/
License:        Pixar AND MIT
#URL:            http://graphics.pixar.com/%%{name}
Url:		https://github.com/PixarAnimationStudios/OpenSubdiv
Source:	        https://github.com/PixarAnimationStudios/OpenSubdiv/archive/v%{upstream_version}%{?prerelease}/%{name}-%{version}%{?prerelease}.tar.gz

# fix linking against libdl (see https://github.com/PixarAnimationStudios/OpenSubdiv/issues/1196)
Patch:         	%{name}-rpath.patch

# make doxygen generated files consistent across builds & architectures
Patch:          opensubdiv-3.5.0-reproducible-docs.patch

# Downstream-only: do not compile static libraries
#
# When compiling shared libraries, do not compile static libraries. This
# patch suffices for Linux, but would have issues on some other platforms,
# and it’s not quite the behavior we would probably suggest upstream if we
# tried.
#
# We need to patch this rather than removing static libraries after the
# fact because the static libraries would still appear in the installed
# CMake files, causing problems for other packages like OpenUSD that want
# to link OpenSubdiv.
Patch:          0001-Downstream-only-do-not-compile-static-libraries.patch

BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  graphviz-devel
BuildRequires:  pkgconfig(glew)
BuildRequires:  pkgconfig(glfw3)
BuildRequires:	pkgconfig(OpenCL)
BuildRequires:	pkgconfig(ptex)
BuildRequires:  pkgconfig(python3)
BuildRequires:  pkgconfig(tbb)
BuildRequires:  pkgconfig(zlib)
BuildRequires:	python3dist(pygments)
# Drop libs subpackage
Obsoletes:	%{name}-libs < %{version}-%{release}
# Doxygen-generated HTML documentation is not suitable for packaging; see
# https://bugzilla.redhat.com/show_bug.cgi?id=2006555 for discussion.
Obsoletes:      %{name}-doc < 3.5.0-10

%description
OpenSubdiv is a set of open source libraries that implement high performance
subdivision surface (subdiv) evaluation on massively parallel CPU and
GPU architectures. 
This codepath is optimized for drawing deforming subdivs with static topology
at interactive framerates.

%package        devel
Summary:        Development files for %{name}
Requires:       %{name}%{?_isa} = %{version}-%{release}

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%prep
%autosetup -p1 -n OpenSubdiv-%{upstream_version}%{?prerelease}

# work around linking glitch
# https://github.com/PixarAnimationStudios/OpenSubdiv/issues/1196
sed -i 's|${PLATFORM_GPU_LIBRARIES}|${PLATFORM_GPU_LIBRARIES} ${CMAKE_DL_LIBS}|' opensubdiv/CMakeLists.txt

# https://docs.fedoraproject.org/en-US/packaging-guidelines/JavaScript/#_compilationminification
find . -type f -name '*.min.js' -print -delete

%build
%cmake \
       -DCMAKE_INSTALL_PREFIX=%{_prefix} \
       -DCMAKE_LIBDIR_BASE=%{_libdir} \
       -DGLEW_LOCATION=%{_libdir} \
       -DGLFW_LOCATION=%{_libdir} \
       -DNO_CLEW=1 \
       -DNO_CUDA=1 \
       -DNO_DOC=1\
       -DNO_EXAMPLES=1 \
       -DNO_GLFW_X11=1 \
       -DNO_OPENCL=1 \
       -DNO_METAL=1 \
       -DNO_REGRESSION=1 \
       -DNO_TUTORIALS=1 \
       -DOpenGL_GL_PREFERENCE=GLVND \
       -DTBB_LOCATION=%{_libdir}
%cmake_build

%{?_with_tests:
%check
make test V=1
}

%install
%cmake_install

%files
%license LICENSE.txt
%doc README.md
%{_libdir}/*.so.3.*

%files devel
%doc NOTICE.txt README.md
%{_includedir}/*
%{_libdir}/*.so
%{_libdir}/cmake/OpenSubdiv/

%changelog
## START: Generated by rpmautospec
* Thu Jul 10 2025 Luya Tshimbalanga <luya@fedoraproject.org> - 3.6.1-2
- Uncommitted changes

* Fri Jun 27 2025 Luya Tshimbalanga <luya@fedoraproject.org> - 3.6.1-1
- Update to 3_6_1 (rhbz#2375010)

* Tue May 06 2025 Benjamin A. Beasley <code@musicinmybrain.net> - 3.6.0-5
- Do not compile static libraries
- Ensure they do not appear in installed CMake files

* Fri Jan 17 2025 Fedora Release Engineering <releng@fedoraproject.org> - 3.6.0-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_42_Mass_Rebuild

* Fri Nov 01 2024 Yaakov Selkowitz <yselkowi@redhat.com> - 3.6.0-3
- Fix build with ptex 2.4.3

* Thu Jul 18 2024 Fedora Release Engineering <releng@fedoraproject.org> - 3.6.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_41_Mass_Rebuild

* Sun Apr 14 2024 Luya Tshimbalanga <luya@fedoraproject.org> - 3.6.0-1
- Update to 3.6.0

* Fri Jan 26 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 3.5.0-14
- Drop the -doc subpackage due to Doxygen guidelines issues

* Fri Jan 26 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 3.5.0-13
- Add missing license file in -doc subpackage

* Fri Jan 26 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 3.5.0-12
- Better handle bundled and pre-minified tipuesearch JS

* Fri Jan 26 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 3.5.0-11
- Correct license to Pixar AND MIT

* Thu Jan 25 2024 Fedora Release Engineering <releng@fedoraproject.org> - 3.5.0-10
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Sun Jan 21 2024 Fedora Release Engineering <releng@fedoraproject.org> - 3.5.0-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Wed Jan 17 2024 Jonathan Wakely <jwakely@redhat.com> - 3.5.0-8
- Build against tbb2020.3 instead of tbb

* Wed Jan 17 2024 Jonathan Wakely <jwakely@redhat.com> - 3.5.0-7
- Rebuilt for Boost 1.83

* Thu Jul 20 2023 Fedora Release Engineering <releng@fedoraproject.org> - 3.5.0-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_39_Mass_Rebuild

* Thu Jan 19 2023 Fedora Release Engineering <releng@fedoraproject.org> - 3.5.0-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_38_Mass_Rebuild

* Tue Jan 03 2023 Todd Zullinger <tmz@pobox.com> - 3.5.0-4
- make doxygen generated files consistent across builds/arches

* Tue Jan 03 2023 Luya Tshimbalanga <luya@fedoraproject.org> - 3.5.0-3
- Drop libs subpackage and move version .so to core

* Mon Jan 02 2023 Luya Tshimbalanga <luya@fedoraproject.org> - 3.5.0-2
- Disable doc subpackage due to strange failure

* Mon Jan 02 2023 Luya Tshimbalanga <luya@fedoraproject.org> - 3.5.0-1
- Update to 3.5.0

* Fri Jul 22 2022 Fedora Release Engineering <releng@fedoraproject.org> - 3.4.4-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_37_Mass_Rebuild

* Thu Jan 20 2022 Fedora Release Engineering <releng@fedoraproject.org> - 3.4.4-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_36_Mass_Rebuild

* Thu Jul 22 2021 Fedora Release Engineering <releng@fedoraproject.org> - 3.4.4-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_35_Mass_Rebuild

* Wed May 19 2021 Luya Tshimbalanga <luya@fedoraproject.org> - 3.4.4-1
- Update to 3.4.4
- Rebuild for ptex 2.4.0

* Fri Feb 05 2021 Luya Tshimbalanga <luya@fedoraproject.org> - 3.4.4-0.1.RC1
- Update to 3.4.4 RC1
- Enable ptex support

* Mon Sep 21 2020 Luya Tshimbalanga <luya@fedoraproject.org> - 3.4.3-1
- Update to 3.4.3
- Port Mageia patch for building with Python 3 dependency
- Add doc subpackage
- Disable OpenCL due to upstream bug

* Sat Aug 01 2020 Fedora Release Engineering <releng@fedoraproject.org> - 3.4.0-6
- Second attempt - Rebuilt for
  https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Tue Jul 28 2020 Fedora Release Engineering <releng@fedoraproject.org> - 3.4.0-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Wed Jan 29 2020 Fedora Release Engineering <releng@fedoraproject.org> - 3.4.0-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_32_Mass_Rebuild

* Mon Oct 14 2019 Luya Tshimbalanga <luya@fedoraproject.org> - 3.4.0-3
- Remove rpath
- Remove unneeded ldconfig_scriptlets macro
- Improve spec file upon review (rhbz #1762155)

* Mon Oct 14 2019 Luya Tshimbalanga <luya@fedoraproject.org> - 3.4.0-2
- Adjust maximum line limit on description

* Mon Oct 14 2019 Luya Tshimbalanga <luya@fedoraproject.org> - 3.4.0-1
- Initial package

## END: Generated by rpmautospec
